@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Exporter::Shiny;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 our %EMOJI;
 
@@ -258,6 +258,23 @@ BEGIN {
             41,  239, 190, 159, 79,  239, 190, 159, 41,  46,  239, 189,
             161, 239, 190, 159
         ],
+        fu => [
+            225, 149, 149, 226, 149, 143, 32,  205, 161, 225,
+            181, 148, 32,  226, 128, 184, 32,  205, 161, 225,
+            181, 148, 32,  226, 149, 143, 229, 135, 184
+        ],
+        vision => [ 40, 45, 40, 45, 40, 45, 95, 45, 41, 45, 41, 45, 41 ],
+        eyes   => [
+            226, 149, 173, 40,  226, 151, 149, 226, 151, 149, 32,  226,
+            151, 137, 224, 183, 180, 226, 151, 137, 32,  226, 151, 149,
+            226, 151, 149, 41,  226, 149, 174
+        ],
+        wall => [
+            226, 148, 180, 226, 148, 172, 226, 148,
+            180,   226, 148, 164, 239, 189, 165, 95,
+            239,   189, 165, 226, 148, 156, 226, 148,
+            180,   226, 148, 172, 226, 148, 180
+        ],
     );
 }
 
@@ -270,7 +287,7 @@ Acme::AsciiEmoji - Ascii Emoji's
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =cut
 
@@ -1118,6 +1135,50 @@ sub punch {
     return ascii_emoji('punch');
 }
 
+=head2 fu
+
+ᕕ╏ ͡ᵔ ‸ ͡ᵔ ╏凸
+*fu*
+
+=cut
+
+sub fu {
+    return ascii_emoji('fu');
+}
+
+=head2 vision
+
+(-(-(-_-)-)-)
+vision
+
+=cut
+
+sub vision {
+    return ascii_emoji('vision');
+}
+
+=head2 eyes
+
+╭(◕◕ ◉෴◉ ◕◕)╮
+eyes
+
+=cut
+
+sub eyes {
+    return ascii_emoji('eyes');
+}
+
+=head2 wall
+
+┴┬┴┤･_･├┴┬┴
+wall
+
+=cut
+
+sub wall {
+    return ascii_emoji('wall');
+}
+
 =head1 AUTHOR
 
 Robert Acock, C<< <thisusedtobeanemail at gmail.com> >>
